@@ -1,6 +1,5 @@
 # Copyright (c) 2011, SD Elements. See LICENSE.txt for details.
 
-from datetime import datetime
 import logging
 from re import compile
 
@@ -9,7 +8,7 @@ from django.contrib.auth import logout
 from django.core.exceptions import ImproperlyConfigured
 from django.core.urlresolvers import reverse
 from django.http import HttpResponseRedirect, HttpResponse
-from django.utils import simplejson as json
+from django.utils import simplejson as json, timezone
 import django.views.static
 
 from password_expiry import password_is_expired
@@ -178,19 +177,22 @@ class SessionExpiryPolicyMiddleware:
         is the case. We set the last activity time to now() if the session
         is still active.
         """
-        now = datetime.now()
+        now = timezone.now()
 
         # If the session has no start time or last activity time, set those
         # two values. We assume we have a brand new session.
-        if (SessionExpiryPolicyMiddleware.START_TIME_KEY not in request.session
-                or SessionExpiryPolicyMiddleware.LAST_ACTIVITY_KEY not in request.session):
+        if (self.START_TIME_KEY not in request.session or
+            self.LAST_ACTIVITY_KEY not in request.session or
+            timezone.is_naive(request.session[self.START_TIME_KEY]) or
+            timezone.is_naive(request.session[self.LAST_ACTIVITY_KEY])):
+
             logger.debug("New session %s started: %s" % (request.session.session_key, now))
-            request.session[SessionExpiryPolicyMiddleware.START_TIME_KEY] = now
-            request.session[SessionExpiryPolicyMiddleware.LAST_ACTIVITY_KEY] = now
+            request.session[self.START_TIME_KEY] = now
+            request.session[self.LAST_ACTIVITY_KEY] = now
             return
 
-        start_time = request.session[SessionExpiryPolicyMiddleware.START_TIME_KEY]
-        last_activity_time = request.session[SessionExpiryPolicyMiddleware.LAST_ACTIVITY_KEY]
+        start_time = request.session[self.START_TIME_KEY]
+        last_activity_time = request.session[self.LAST_ACTIVITY_KEY]
         logger.debug("Session %s started: %s" % (request.session.session_key, start_time))
         logger.debug("Session %s last active: %s" % (request.session.session_key, last_activity_time))
 
